@@ -1,6 +1,7 @@
 "llogistic" <- function(
 fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), 
-ss = c("1", "2", "3"), ssfct = NULL, fctName, fctText)
+ss = c("1", "2", "3"), ssfct = NULL, 
+fctName, fctText)
 {
     ## Matching 'adjust' argument
     ss <- match.arg(ss)
@@ -70,183 +71,14 @@ if (FALSE) {  ## will work once plotFct does not depend on drcFct
     }    
 
     ## Defining the self starter function
-    
-    ## Defining self starter function based on supplied function
+
+    ## Defining self starter function based on supplied function   
     if (!is.null(ssfct))
     {
         ssfct <- ssfct
     } else {
-        
-    ## Version 1 (default)    
-    if (ss == "1")
-    {
-        ssfct <- function(dframe)
-        {
-            x <- dframe[, 1]
-            y <- dframe[, 2]
-
-            startVal <- rep(0, numParm)
-
-            startVal[3] <- max(y) + 0.001  # the d parameter
-            startVal[2] <- min(y) - 0.001  # the c parameter
-            startVal[5] <- 1  # better choice may be possible!        
-        
-            if (length(unique(x))==1) {return((c(NA, NA, startVal[3], NA, NA))[notFixed])}  
-            # only estimate of upper limit if a single unique dose value 
-
-            indexT2 <- (x > 0)
-#            if (!any(indexT2)) {return((rep(NA, numParm))[notFixed])}  # for negative dose value
-            x2 <- x[indexT2]
-            y2 <- y[indexT2]
-
-            startVal[c(1,4)] <- find.be2(x2, y2, startVal[2] - 0.001, startVal[3])
-            # 0.001 to avoid 0 in the denominator
-
-#            logitTrans <- log((startVal[3]-resp3)/(resp3-startVal[2]+0.001))  
-#            logitFit <- lm(logitTrans ~ log(dose3))
-#            startVal[4] <- exp((-coef(logitFit)[1]/coef(logitFit)[2]))  # the e parameter
-#            startVal[1] <- coef(logitFit)[2]  # the b parameter
-        
-            return(startVal[notFixed])
-        }
+        ssfct <- LL.ssf(ss, fixed)
     }
-
-    ## Version 2
-    if (ss == "2")
-    {
-        ssfct <- function(dframe, doseScaling, respScaling)
-        {
-            x <- dframe[, 1] / doseScaling
-            y <- dframe[, 2] / respScaling
-
-#            startVal <- rep(0, numParm)
-
-#            startVal[3] <- max(resp3) + 0.001  # the d parameter
-#            startVal[3] <- ifelse(notFixed[3], 1.05*max(y), fixed[3])
-#            startVal[3] <- mean(resp3[dose2 == max(dose2)]) + 0.001
-        
-#            startVal[2] <- min(resp3) - 0.001  # the c parameter
-#            startVal[2] <- ifelse(notFixed[2], 0.95*min(y), fixed[2])
-#            startVal[2] <- mean(resp3[dose2 == min(dose2)]) + (1e-8)*((max(resp3) - min(resp3))/max(resp3))  
-
-#            miny <- min(y)
-#            if (all.equal(miny, 0))
-#            {
-#                miny <- min(y[y > miny])
-#            } 
-            cVal <- ifelse(notFixed[2], 0.99 * min(y), fixed[2] / respScaling)
-            dVal <- ifelse(notFixed[3], 1.01 * max(y), fixed[3] / respScaling)
-
-#            if (reps)
-#            {
-#                cVal0 <- median(y[x == min(x)])
-#                dVal0 <- median(y[x == max(x)])            
-#                if (cVal0 > dVal0)  # making dVal0 the largest
-#                {
-#                    tval <- cVal0
-#                    cVal0 <- dVal0
-#                    dVal0 <- tval
-#                }
-#        
-#                cVal <- ifelse(notFixed[2], 0.95*cVal0, fixed[2])
-#                dVal <- ifelse(notFixed[3], 1.05*dVal0, fixed[3])                
-#            }  
-
-#            startVal[5] <- 1 
-            fVal <- 1  # need not be updated with value in 'fixed[5]'
-            # better choice than 1 may be possible! 
-            # the f parameter, however, is very rarely a magnitude of 10 larger or smaller
-        
-            if ( length(unique(x)) == 1 ) {return((c(NA, NA, dVal, NA, NA))[notFixed])}  
-            # only estimate of upper limit if a single unique dose value 
-
-            # Cutting away response values close to d
-            indexT1a <- x > 0
-#            indexT1b <- !(y > 0.95*max(y))
-#            indexT2 <- c(max((1:length(y))[!(indexT1a | indexT1b)]):length(y))
-#            x2 <- x[indexT2]
-#            y2 <- y[indexT2]
-            x2 <- x[indexT1a]
-            y2 <- y[indexT1a]
-            
-            print(c(cVal, dVal))
-            beVec <- find.be2(x2, y2, cVal, dVal)
-# These lines are not needed as the b and e parameters are not used in further calculations
-#            bVal <- ifelse(notFixed[1], beVec[1], fixed[1])
-#            eVal <- ifelse(notFixed[4], beVec[2], fixed[4] / doseScaling)
-            bVal <- beVec[1]
-            eVal <- beVec[2]
-            
-#            logitTrans <- log((dVal - y2)/(y2 - cVal))
-#            logitFit <- lm(logitTrans ~ log(x2))       
-#            coefVec <- coef(logitFit)
-#            bVal <- coefVec[2]        
-#            eVal <- exp(-coefVec[1]/bVal)        
-            
-            return(as.vector(c(bVal, cVal, dVal, eVal, fVal)[notFixed]))
-        }
-    }
-
-    ## Version 3
-    if (ss == "3")
-    {
-        ssfct <- function(dframe)
-        {
-            x <- dframe[, 1]
-            y <- dframe[, 2]
-
-            cVal <- ifelse(notFixed[2], 0.99 * min(y), fixed[2])
-            dVal <- ifelse(notFixed[3], 1.01 * max(y), fixed[3])
-            fVal <- 1  # need not be updated with value in 'fixed[5]'
-        
-            if ( length(unique(x)) == 1 ) {return((c(NA, NA, dVal, NA, NA))[notFixed])}  
-            # only estimate of upper limit if a single unique dose value 
-           
-            beVec <- find.be1(x, y, cVal, dVal)
-            bVal <- beVec[1]
-            eVal <- beVec[2]
-            
-            return(as.vector(c(bVal, cVal, dVal, eVal, fVal)[notFixed]))
-        }
-    }
-    }
-
-    ## Finding b and e based on stepwise increments
-    find.be1 <- function(x, y, c, d)
-    {
-        unix <- unique(x)
-        uniy <- tapply(y, x, mean)
-        lenx <- length(unix)
-        
-        j <- 2
-        for (i in 2:lenx)
-        {
-            crit1 <- (uniy[i] > (d + c)/2) && (uniy[i-1] < (d + c)/2)
-            crit2 <- (uniy[i] < (d + c)/2) && (uniy[i-1] > (d + c)/2)
-            if (crit1 || crit2) break
-            j <- j + 1
-        }
-        eVal <- (unix[j] + unix[j-1])/2
-        bVal <- -sign(uniy[j] - uniy[j-1])  # -(uniy[j] - uniy[j-1]) / (unix[j] - unix[j-1])
-        return(as.vector(c(bVal, eVal)))  
-    }
-    
-    ## Finding b and e based on linear regression
-    find.be2 <- function(x, y, c, d)
-    {
-        logitTrans <- log((d - y)/(y - c))  
-
-        lmFit <- lm(logitTrans ~ log(x))
-#        eVal <- exp((-coef(logitFit)[1]/coef(logitFit)[2]))
-#        bVal <- coef(logitFit)[2]
-
-        coefVec <- coef(lmFit)
-        bVal <- coefVec[2]        
-        eVal <- exp(-coefVec[1]/bVal)    
-
-        return(as.vector(c(bVal, eVal)))
-    }
-
    
     ## Defining names
     names <- names[notFixed]
@@ -529,3 +361,226 @@ function(fixed = c(NA, NA, NA), names = c("c", "d", "e"), ...)
     fctText = "Shifted Michaelis-Menten", 
     ...) )
 }
+
+
+#if (FALSE)
+#{   
+#        
+#    ## Version 1 (default)    
+#    if (ss == "1")
+#    {
+#        ssfct <- function(dframe)
+#        {
+#            x <- dframe[, 1]
+#            y <- dframe[, 2]
+#
+#            startVal <- rep(0, numParm)
+#
+#            startVal[3] <- max(y) + 0.001  # the d parameter
+#            startVal[2] <- min(y) - 0.001  # the c parameter
+#            startVal[5] <- 1  # better choice may be possible!        
+#        
+#            if (length(unique(x))==1) {return((c(NA, NA, startVal[3], NA, NA))[notFixed])}  
+#            # only estimate of upper limit if a single unique dose value 
+#
+#            indexT2 <- (x > 0)
+##            if (!any(indexT2)) {return((rep(NA, numParm))[notFixed])}  # for negative dose value
+#            x2 <- x[indexT2]
+#            y2 <- y[indexT2]
+#
+#            startVal[c(1,4)] <- find.be2(x2, y2, startVal[2] - 0.001, startVal[3])
+#            # 0.001 to avoid 0 in the denominator
+#
+##            logitTrans <- log((startVal[3]-resp3)/(resp3-startVal[2]+0.001))  
+##            logitFit <- lm(logitTrans ~ log(dose3))
+##            startVal[4] <- exp((-coef(logitFit)[1]/coef(logitFit)[2]))  # the e parameter
+##            startVal[1] <- coef(logitFit)[2]  # the b parameter
+#        
+#            return(startVal[notFixed])
+#        }
+#    }
+#
+#    if (ss == "1")
+#    {
+#        ssfct <- function(dframe)
+#        {
+#            x <- dframe[, 1]
+#            y <- dframe[, 2]
+#
+#            startVal <- rep(0, numParm)
+#
+#            lenyRange <- 0.001 * diff(range(y))
+#            startVal[3] <- max(y) + lenyRange  # the d parameter
+#            startVal[2] <- min(y) - lenyRange  # the c parameter
+#            startVal[5] <- 1  # better choice may be possible!        
+#        
+##            if (length(unique(x))==1) {return((c(NA, NA, startVal[3], NA, NA))[notFixed])}  
+##            # only estimate of upper limit if a single unique dose value 
+#
+##            indexT2 <- (x > 0)
+###            if (!any(indexT2)) {return((rep(NA, numParm))[notFixed])}  # for negative dose value
+##            x2 <- x[indexT2]
+##            y2 <- y[indexT2]
+#
+##            startVal[c(1,4)] <- find.be2(x2, y2, startVal[2] - lenyRange, startVal[3])
+#            startVal[c(1, 4)] <- find.be3(x, y, startVal[2], startVal[3])
+#            # 0.001 to avoid 0 in the denominator
+#
+##            logitTrans <- log((startVal[3]-resp3)/(resp3-startVal[2]+0.001))  
+##            logitFit <- lm(logitTrans ~ log(dose3))
+##            startVal[4] <- exp((-coef(logitFit)[1]/coef(logitFit)[2]))  # the e parameter
+##            startVal[1] <- coef(logitFit)[2]  # the b parameter
+#        
+#            return(startVal[notFixed])
+#        }
+#    }
+#    
+#    ## Version 2
+#    if (ss == "2")
+#    {
+#        ssfct <- function(dframe, doseScaling, respScaling)
+#        {
+#            x <- dframe[, 1] / doseScaling
+#            y <- dframe[, 2] / respScaling
+#
+##            startVal <- rep(0, numParm)
+#
+##            startVal[3] <- max(resp3) + 0.001  # the d parameter
+##            startVal[3] <- ifelse(notFixed[3], 1.05*max(y), fixed[3])
+##            startVal[3] <- mean(resp3[dose2 == max(dose2)]) + 0.001
+#        
+##            startVal[2] <- min(resp3) - 0.001  # the c parameter
+##            startVal[2] <- ifelse(notFixed[2], 0.95*min(y), fixed[2])
+##            startVal[2] <- mean(resp3[dose2 == min(dose2)]) + (1e-8)*((max(resp3) - min(resp3))/max(resp3))  
+#
+##            miny <- min(y)
+##            if (all.equal(miny, 0))
+##            {
+##                miny <- min(y[y > miny])
+##            } 
+#            cVal <- ifelse(notFixed[2], 0.99 * min(y), fixed[2] / respScaling)
+#            dVal <- ifelse(notFixed[3], 1.01 * max(y), fixed[3] / respScaling)
+#
+##            if (reps)
+##            {
+##                cVal0 <- median(y[x == min(x)])
+##                dVal0 <- median(y[x == max(x)])            
+##                if (cVal0 > dVal0)  # making dVal0 the largest
+##                {
+##                    tval <- cVal0
+##                    cVal0 <- dVal0
+##                    dVal0 <- tval
+##                }
+##        
+##                cVal <- ifelse(notFixed[2], 0.95*cVal0, fixed[2])
+##                dVal <- ifelse(notFixed[3], 1.05*dVal0, fixed[3])                
+##            }  
+#
+##            startVal[5] <- 1 
+#            fVal <- 1  # need not be updated with value in 'fixed[5]'
+#            # better choice than 1 may be possible! 
+#            # the f parameter, however, is very rarely a magnitude of 10 larger or smaller
+#        
+#            if ( length(unique(x)) == 1 ) {return((c(NA, NA, dVal, NA, NA))[notFixed])}  
+#            # only estimate of upper limit if a single unique dose value 
+#
+#            # Cutting away response values close to d
+#            indexT1a <- x > 0
+##            indexT1b <- !(y > 0.95*max(y))
+##            indexT2 <- c(max((1:length(y))[!(indexT1a | indexT1b)]):length(y))
+##            x2 <- x[indexT2]
+##            y2 <- y[indexT2]
+#            x2 <- x[indexT1a]
+#            y2 <- y[indexT1a]
+#            
+#            print(c(cVal, dVal))
+#            beVec <- find.be2(x2, y2, cVal, dVal)
+## These lines are not needed as the b and e parameters are not used in further calculations
+##            bVal <- ifelse(notFixed[1], beVec[1], fixed[1])
+##            eVal <- ifelse(notFixed[4], beVec[2], fixed[4] / doseScaling)
+#            bVal <- beVec[1]
+#            eVal <- beVec[2]
+#            
+##            logitTrans <- log((dVal - y2)/(y2 - cVal))
+##            logitFit <- lm(logitTrans ~ log(x2))       
+##            coefVec <- coef(logitFit)
+##            bVal <- coefVec[2]        
+##            eVal <- exp(-coefVec[1]/bVal)        
+##            
+#            return(as.vector(c(bVal, cVal, dVal, eVal, fVal)[notFixed]))
+#        }
+#    }
+#
+#    ## Version 3
+#    if (ss == "3")
+#    {
+#        ssfct <- function(dframe)
+#        {
+#            x <- dframe[, 1]
+#            y <- dframe[, 2]
+#
+#            cVal <- ifelse(notFixed[2], 0.99 * min(y), fixed[2])
+#            dVal <- ifelse(notFixed[3], 1.01 * max(y), fixed[3])
+#            fVal <- 1  # need not be updated with value in 'fixed[5]'
+#        
+#            if ( length(unique(x)) == 1 ) {return((c(NA, NA, dVal, NA, NA))[notFixed])}  
+#            # only estimate of upper limit if a single unique dose value 
+#           
+#            beVec <- find.be1(x, y, cVal, dVal)
+#            bVal <- beVec[1]
+#            eVal <- beVec[2]
+#            
+#            return(as.vector(c(bVal, cVal, dVal, eVal, fVal)[notFixed]))
+#        }
+#    }
+#
+#    ## Finding b and e based on stepwise increments
+#    find.be1 <- function(x, y, c, d)
+#    {
+#        unix <- unique(x)
+#        uniy <- tapply(y, x, mean)
+#        lenx <- length(unix)
+#        
+#        j <- 2
+#        for (i in 2:lenx)
+#        {
+#            crit1 <- (uniy[i] > (d + c)/2) && (uniy[i-1] < (d + c)/2)
+#            crit2 <- (uniy[i] < (d + c)/2) && (uniy[i-1] > (d + c)/2)
+#            if (crit1 || crit2) break
+#            j <- j + 1
+#        }
+#        eVal <- (unix[j] + unix[j-1])/2
+#        bVal <- -sign(uniy[j] - uniy[j-1])  # -(uniy[j] - uniy[j-1]) / (unix[j] - unix[j-1])
+#        return(as.vector(c(bVal, eVal)))  
+#    }
+#    
+#    ## Finding b and e based on linear regression
+#    find.be2 <- function(x, y, c, d)
+#    {
+#        logitTrans <- log((d - y)/(y - c))  
+#
+#        lmFit <- lm(logitTrans ~ log(x))
+##        eVal <- exp((-coef(logitFit)[1]/coef(logitFit)[2]))
+##        bVal <- coef(logitFit)[2]
+#
+#        coefVec <- coef(lmFit)
+#        bVal <- coefVec[2]        
+#        eVal <- exp(-coefVec[1]/bVal)    
+#
+#        return(as.vector(c(bVal, eVal)))
+#    }
+#
+#    ## Finding b and e based on linear regression
+#    find.be3 <- function(x, y, c, d)
+#    {
+#        logitTrans <- log((d - y)/(y - c))  
+#
+#        lmFit <- lm(logitTrans ~ log(x), subset = x > 0)
+#        coefVec <- coef(lmFit)
+#        bVal <- coefVec[2]        
+#        eVal <- exp(-coefVec[1] / bVal)
+#
+#        print(as.vector(c(bVal, eVal)))
+#        return(as.vector(c(bVal, eVal)))
+#    }    
+#}
\ No newline at end of file
